@@ -239,8 +239,10 @@ public class DefaultGroovyCompiler implements Compiler {
                 compiledSourceInfoMap.put(source, compiledSourceInfo);
             });
 
+            // extra object to prevent compiler warning (raw List in Groovy 2, List<GroovyClass> in Groovy 3)
+            Object cuClassesObject = cu.getClasses();
             @SuppressWarnings("unchecked")
-            final Map<String, Bytecode> bytecodeMap = ((List<GroovyClass>)cu.getClasses()).stream()
+            final Map<String, Bytecode> bytecodeMap = ((List<GroovyClass>)cuClassesObject).stream()
                     .collect(Collectors.toMap(GroovyClass::getName, c -> new Bytecode(c.getName(), c.getBytes())));
 
             final Code code;
@@ -491,8 +493,10 @@ public class DefaultGroovyCompiler implements Compiler {
         // the lock for calls to GrapeEngine methods
         static volatile Object lock;
 
-        // default depth of wrapped GrapeEngine plus one
-        static volatile int defaultDepth;
+        // default callee depth of (unwrapped) GrapeEngine instance;
+        // value has been 3 up to at least Groovy 4; since Groovy 3
+        // publicly declared as GrapeEngine.DEFAULT_CALLEE_DEPTH
+        static volatile int grapeInstanceDefaultCalleeDepth;
 
         // the wrapped engine
         final GrapeEngine innerEngine;
@@ -503,7 +507,7 @@ public class DefaultGroovyCompiler implements Compiler {
         }
 
         // sets the engine instance in the Grape class (only once, idempotent)
-        static void wrap(Object newLock) {
+        static void wrap(final Object newLock) {
             synchronized (GrengineGrapeEngine.class) {
 
                 // already wrapped?
@@ -518,26 +522,21 @@ public class DefaultGroovyCompiler implements Compiler {
                     }
                 }
 
-                // verify preconditions and get GrapeIvy DEFAULT_DEPTH via reflection
-                final Class<?> grapeEngineClass = Grape.getInstance().getClass();
-                if (!grapeEngineClass.getName().equals("groovy.grape.GrapeIvy")) {
+                // verify preconditions
+                final Class<?> grapeIvyClass = Grape.getInstance().getClass();
+                if (!grapeIvyClass.getName().equals("groovy.grape.GrapeIvy")) {
                     throw new IllegalStateException("Unable to wrap GrapeEngine in Grape.class " +
-                            "(current GrapeEngine is " + grapeEngineClass.getName() +
+                            "(current GrapeEngine is " + grapeIvyClass.getName() +
                             ", supported is groovy.grape.GrapeIvy).");
                 }
-                final Field defaultDepthField;
+
                 try {
-                    defaultDepthField = grapeEngineClass.getDeclaredField("DEFAULT_DEPTH");
-                } catch (NoSuchFieldException e) {
-                    throw new IllegalStateException("Unable to wrap GrapeEngine in Grape.class " +
-                            "(no static field GrapeIvy.DEFAULT_DEPTH)");
-                }
-                defaultDepthField.setAccessible(true);
-                try {
-                    defaultDepth = defaultDepthField.getInt(grapeEngineClass) + 1;
-                } catch (IllegalAccessException e) {
-                    throw new IllegalStateException("Unable to wrap GrapeEngine in Grape.class " +
-                            "(could not read static int field GrapeIvy.DEFAULT_DEPTH: " + e + ")");
+                    // Groovy 3 and later
+                    final Field field = GrapeEngine.class.getDeclaredField("DEFAULT_CALLEE_DEPTH");
+                    grapeInstanceDefaultCalleeDepth = field.getInt(GrapeEngine.class);
+                } catch (Throwable t) {
+                    // earlier Groovy
+                    grapeInstanceDefaultCalleeDepth = 3;
                 }
 
                 // wrap
@@ -570,7 +569,7 @@ public class DefaultGroovyCompiler implements Compiler {
                     }.unwrap();
                 }
                 lock = null;
-                defaultDepth = 0;
+                grapeInstanceDefaultCalleeDepth = 0;
             }
         }
 
@@ -585,7 +584,7 @@ public class DefaultGroovyCompiler implements Compiler {
         @SuppressWarnings({ "rawtypes", "unchecked" })
         public Object grab(final Map args) {
             synchronized(lock) {
-                args.computeIfAbsent(CALLEE_DEPTH_KEY, k -> defaultDepth + 1);
+                adjustCalleeDepth(args);
                 // apply grab also to runtime loader, if present
                 final Object obj = args.get(CLASS_LOADER_KEY);
                 if (obj instanceof CompileTimeGroovyClassLoader) {
@@ -604,7 +603,7 @@ public class DefaultGroovyCompiler implements Compiler {
         @SuppressWarnings({ "rawtypes", "unchecked" })
         public Object grab(final Map args, final Map... dependencies) {
             synchronized(lock) {
-                args.computeIfAbsent(CALLEE_DEPTH_KEY, k -> defaultDepth);
+                adjustCalleeDepth(args);
                 // apply grab also to runtime loader, if present
                 final Object obj = args.get(CLASS_LOADER_KEY);
                 if (obj instanceof CompileTimeGroovyClassLoader) {
@@ -630,7 +629,7 @@ public class DefaultGroovyCompiler implements Compiler {
         @SuppressWarnings({ "rawtypes", "unchecked" })
         public URI[] resolve(final Map args, final Map... dependencies) {
             synchronized(lock) {
-                args.computeIfAbsent(CALLEE_DEPTH_KEY, k -> defaultDepth);
+                adjustCalleeDepth(args);
                 return innerEngine.resolve(args, dependencies);
             }
         }
@@ -658,6 +657,12 @@ public class DefaultGroovyCompiler implements Compiler {
             }
         }
 
+        private static void adjustCalleeDepth(Map<String, Object> args) {
+            Object calleeDepthObj = args.get(CALLEE_DEPTH_KEY);
+            int calleeDepth = (calleeDepthObj == null) ? grapeInstanceDefaultCalleeDepth : (int)calleeDepthObj;
+            args.put(CALLEE_DEPTH_KEY, calleeDepth + 1);
+        }
+
     }
 
 }
